@@ -69,15 +69,20 @@ class AwsPrototypingChecks(
         *,
         log_ignores: typing.Optional[builtins.bool] = None,
         reports: typing.Optional[builtins.bool] = None,
+        suppression_ignore_condition: typing.Optional[_cdk_nag_263d9695.INagSuppressionIgnore] = None,
         verbose: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''
         :param log_ignores: Whether or not to log triggered rules that have been suppressed as informational messages (default: false).
         :param reports: Whether or not to generate CSV compliance reports for applied Stacks in the App's output directory (default: true).
+        :param suppression_ignore_condition: Conditionally prevent rules from being suppressed (default: no user provided condition).
         :param verbose: Whether or not to enable extended explanatory descriptions on warning, error, and logged ignore messages (default: false).
         '''
         props = _cdk_nag_263d9695.NagPackProps(
-            log_ignores=log_ignores, reports=reports, verbose=verbose
+            log_ignores=log_ignores,
+            reports=reports,
+            suppression_ignore_condition=suppression_ignore_condition,
+            verbose=verbose,
         )
 
         jsii.create(self.__class__, self, [props])
